@@ -159,7 +159,7 @@ class SKU:
                 if attribute['defindex'] == 214 and item['quality'] == 5: TEMPLATE["quality2"] = attribute["value"]
                 if attribute["defindex"] == 229: TEMPLATE["craftnumber"] = attribute["value"]
                 if attribute["defindex"] == 187: TEMPLATE["crateseries"] = attribute["float_value"]
-                if 2000 < attribute['defindex'] <= 2009 and attribute.get("attributes"):
+                if 2000 <= attribute['defindex'] <= 2009 and attribute.get("attributes"):
                     for attr in attribute["attributes"]:
                         if attr["defindex"] == 2012: TEMPLATE["target"] = attr["float_value"]
                 if attribute.get("is_output") and attribute["is_output"] is True: 
